//! A utility library to calculate mean and standard deviation with online
//! algorithms.
//!
//! # Examples
//!
//! ```rust
//! use meansd::MeanSD;
//!
//! let mut meansd = MeanSD::default();
//!
//! meansd.update(1.0);
//! meansd.update(2.0);
//! meansd.update(3.0);
//!
//! assert_eq!(meansd.size(), 3);
//! assert_eq!(meansd.mean(), 2.0);
//! assert_eq!(meansd.sd(), 1.0);
//! ```

#![deny(clippy::all)]
#![warn(clippy::pedantic, clippy::nursery, clippy::cargo)]

mod binned;
mod meansd;
mod sd_mode;

pub use crate::binned::Bin;
pub use crate::binned::Binned;
pub use crate::meansd::MeanSD;
pub use crate::sd_mode::StandardDeviationMode;
